@@ -107,10 +107,8 @@ encounter.put(
         const dietIds = JSON.parse(req.body.dietIds);
         await encounterObject.setDiets(dietIds);
       }
-
       await encounterObject.update({ ...req.body, systemNote }, user);
     });
-
     res.send(encounterObject);
   }),
 );
@@ -234,12 +232,12 @@ encounterRelations.get(
     });
 
     const data = await Promise.all(
-      objects.map(async ir => {
+      objects.map(async (ir) => {
         return {
           ...ir.forResponse(),
           ...(includeNote ? await ir.extractNotes() : undefined),
-          areas: ir.areas.map(a => a.forResponse()),
-          results: ir.results.map(result => result.forResponse()),
+          areas: ir.areas.map((a) => a.forResponse()),
+          results: ir.results.map((result) => result.forResponse()),
         };
       }),
     );
@@ -260,7 +258,7 @@ encounterRelations.get(
       where: { recordId: encounterId, recordType: 'Encounter' },
     });
     const noteTypeToCount = {};
-    noteTypeCounts.forEach(n => {
+    noteTypeCounts.forEach((n) => {
       noteTypeToCount[n.noteType] = n.count;
     });
     res.send({ data: noteTypeToCount });
@@ -470,7 +468,7 @@ async function getAnswersWithHistory(req) {
     },
   );
 
-  const data = result.map(r => r.result);
+  const data = result.map((r) => r.result);
   return { count, data };
 }
 
@@ -511,7 +509,7 @@ encounterRelations.get(
       },
     });
 
-    const responseIds = dateAnswers.map(dateAnswer => dateAnswer.responseId);
+    const responseIds = dateAnswers.map((dateAnswer) => dateAnswer.responseId);
 
     const answers = await SurveyResponseAnswer.findAll({
       where: {
@@ -522,10 +520,10 @@ encounterRelations.get(
     });
 
     const data = answers
-      .map(answer => {
+      .map((answer) => {
         const { responseId } = answer;
         const recordedDateAnswer = dateAnswers.find(
-          dateAnswer => dateAnswer.responseId === responseId,
+          (dateAnswer) => dateAnswer.responseId === responseId,
         );
         const recordedDate = recordedDateAnswer.body;
         return { ...answer.dataValues, recordedDate };
@@ -584,29 +582,17 @@ encounterRelations.get(
 
 const encounterTasksQuerySchema = z.object({
   order: z.preprocess(
-    value => (typeof value === 'string' ? value.toUpperCase() : value),
-    z
-      .enum(['ASC', 'DESC'])
-      .optional()
-      .default('ASC'),
+    (value) => (typeof value === 'string' ? value.toUpperCase() : value),
+    z.enum(['ASC', 'DESC']).optional().default('ASC'),
   ),
-  orderBy: z
-    .enum(['dueTime', 'name'])
-    .optional()
-    .default('dueTime'),
+  orderBy: z.enum(['dueTime', 'name']).optional().default('dueTime'),
   statuses: z
     .array(z.enum(Object.values(TASK_STATUSES)))
     .optional()
     .default([TASK_STATUSES.TODO]),
   assignedTo: z.string().optional(),
-  page: z.coerce
-    .number()
-    .optional()
-    .default(0),
-  rowsPerPage: z.coerce
-    .number()
-    .optional()
-    .default(10),
+  page: z.coerce.number().optional().default(0),
+  rowsPerPage: z.coerce.number().optional().default(10),
 });
 encounterRelations.get(
   '/:id/tasks',
@@ -653,7 +639,7 @@ encounterRelations.get(
       offset: page * rowsPerPage,
       include: Task.getFullReferenceAssociations(),
     });
-    const results = queryResults.map(x => x.forResponse());
+    const results = queryResults.map((x) => x.forResponse());
 
     const count = await Task.count(baseQueryOptions);
     res.send({ data: results, count });
