@@ -1,4 +1,3 @@
-import config from 'config';
 import express from 'express';
 
 import {
@@ -19,7 +18,7 @@ const globalMedicationRequests = permissionCheckingRouter('list', 'EncounterMedi
 globalMedicationRequests.get('/$', (req, res, next) =>
   paginatedGetList('EncounterMedication', '', {
     additionalFilters: {
-      '$encounter.location.facility.id$': config.serverFacilityId,
+      '$encounter.location.facility.id$': req.query.facilityId,
     },
     include: [
       {
